==> spip_3.2.11.orig.tar.xz: plugins-dist/medias/lang/medias_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'affichage_documents_en_cases' => 'عرض في خانات',
	'affichage_documents_en_grand' => 'عرض كبير',
	'affichage_documents_en_liste_compacte' => 'عرض في لائحة موجزة',
	'aucun_audio' => 'لا يوجد ملفات صوت',
	'aucun_document' => 'لا يوجد مستندات',
	'aucun_file' => 'لا يوجد مستندات',
	'aucun_image' => 'لا يوجد صور',
	'aucun_video' => 'لا يوجد ملفات فيديو',
	'aucune_utilisation' => 'هذا المستند غير مستخدم',
	'aucune_vignette' => 'لا يوجد مصغرات',

	// B
	'bouton_ajouter_document' => 'إضافة مستند',
	'bouton_ajouter_image' => 'إضافة صورة',
	'bouton_ajouter_image_document' => 'إضافة صورة أو مستند',
	'bouton_attacher_document' => 'ربط
',
	'bouton_copier_local' => 'نسخ في الموقع',
	'bouton_download_depuis' => 'منذ:',
	'bouton_download_local' => 'جهازي',
	'bouton_download_par_ftp' => 'جهاز الخدمة',
	'bouton_download_par_mediatheque' => 'مكتبة المستندات',
	'bouton_download_sur_le_web' => 'شبكة إنترنت',
	'bouton_enlever_document' => 'إزالة الربط',
	'bouton_enlever_supprimer_document' => 'حذف',
	'bouton_enlever_supprimer_document_confirmation' => 'هل تريد فعلاً حذف المستند؟',
	'bouton_modifier_document' => 'تعديل',
	'bouton_parcourir' => 'عرض...',
	'bouton_refresh_document' => 'تحديث المستند',
	'bouton_remplacer_document' => 'تبديل هذا المستند',
	'bouton_remplacer_image' => 'تبديل هذه الصورة',
	'bouton_remplacer_image_document' => 'استبدال بصورة إو مستند',
	'bouton_supprimer' => 'حذف',
	'bouton_supprimer_tous_orphelins' => 'حذف كل المستندات غير المستخدمة',
	'bouton_supprimer_tous_orphelins_confirmation' => 'هل تريد فعلاً حذف @nb@ مستند غير مربوط؟',
	'bouton_upload' => 'تنزيل',

	// D
	'des_audios' => '@nb@ ملف صوت',
	'des_documents' => '@nb@ مستند',
	'des_files' => '@nb@ مستند',
	'des_images' => '@nb@ صورة',
	'des_utilisations' => '@nb@ استخدام',
	'des_videos' => '@nb@ ملف فيديو',
	'descriptif' => 'وصف',
	'details_document' => 'التفاصيل',
	'details_document_afficher_masquer' => 'عرض \\ حجب تفاصيل المستند',
	'document_attache_succes' => 'لقد تمت فعلاً إضافة المستند',
	'document_copie_locale_succes' => 'لقد تم فعلاً نسخ الملف في الموقع',
	'document_installe_succes' => 'لقد تم فعلاً تحميل الملف',
	'document_vu' => 'مدرج في النص',
	'documents' => 'مكتبة المستندات',
	'documents_brises' => 'رابط مكسور',
	'documents_distants' => 'بعيدة',
	'documents_locaux' => 'محلية',
	'documents_non_publies' => 'غير منشورة',
	'documents_orphelins' => 'غير مستخدمة',
	'documents_publies' => 'منشورة',
	'documents_tous' => 'الكل',
	'double_clic_inserer_doc' => 'النقر المزدوج لإدراج هذا الاختصار في النص',

	// E
	'entree_dimensions' => 'الحجم:',
	'entree_titre_document' => 'اسم المستند:',
	'entree_titre_image' => 'اسم الصورة:',
	'erreur_aucun_document' => 'لا وجود لهذا المستند في المكتبة',
	'erreur_aucun_fichier' => 'لم يتم العثور على أي ملف',
	'erreur_autorisation' => 'فشل الاجازة',
	'erreur_chemin_distant' => 'لم يتم العثور على الملف البعيد @nom@',
	'erreur_chemin_ftp' => 'لم يتم العثور على الملف المحدد في الخادم',
	'erreur_copie_fichier' => 'لا يمكن نسخ الملف @nom@',
	'erreur_deplacement_impossible' => 'النقل مسحيل.',
	'erreur_dossier_tmp_manquant' => 'مجلد مؤقت لتحميل الملفات غير موجود',
	'erreur_ecriture_fichier' => 'حصل خطأ خلال كتابة الملف على القرص الثابت',
	'erreur_format_fichier_image' => 'لا يناسب تنسيق @nom@ ملف صورة',
	'erreur_indiquez_un_fichier' => 'تحديد ملف!',
	'erreur_insertion_document_base' => 'لا يمكن تسجيل المستند @fichier@ في قاعدة البيانات',
	'erreur_objet_absent' => 'المعلومات المستقاة غير كاملة.',
	'erreur_suppression_vignette' => 'حصل خطأ لدى حذف المصغر',
	'erreur_upload_type_interdit' => 'تحميل ملفات من نوع @nom@ غير مسموح',
	'erreur_upload_vignette' => 'خطأ خلال تحميل المصغر @nom@',
	'erreurs' => '@nb@ خطأ',
	'erreurs_voir' => 'عرض @nb@ خطأ',

	// F
	'fichier_distant' => 'ملف بعيد',
	'fichier_manquant' => 'ملف غير موجود',
	'fichier_modifie' => 'تم تعديل هذا المستند. أنقر على حفظ.',
	'format_date_incorrect' => 'التاريخ او الوقت غير صحيحين',

	// I
	'icone_creer_document' => 'إضافة مستند',
	'id' => 'رقم',
	'image_tourner_180' => 'دوران 180°',
	'image_tourner_droite' => 'دوران 90° يمين',
	'image_tourner_gauche' => 'دوران 90° يسار',
	'info_dimensions_image' => 'الأبعاد',
	'info_doc_max_poids' => 'يحب ان يكون حجم المستندات أقل من @maxi@ (حجم هذا الملف يبلغ @actuel@).',
	'info_document' => 'المستند',
	'info_document_indisponible' => 'هذا المستند غير متوافر',
	'info_documents' => 'المستندات',
	'info_duree' => 'المدة',
	'info_gauche_numero_document' => 'مستند رقم',
	'info_hauteur' => 'ارتفاع',
	'info_heure' => 'الساعة',
	'info_illustrations' => 'الرسوم التوضيحية',
	'info_image_max_poids' => 'يحب ان يكون حجم الصور أقل من @maxi@ (حجم هذا الملف يبلغ @actuel@).',
	'info_image_max_taille' => 'يحب ان يكون حجم الصور أقل من @maxi@ (حجم هذا الملف يبلغ @actuel@).',
	'info_inclusion_directe' => 'ضم مباشر:',
	'info_inclusion_vignette' => 'ضم المصغر:',
	'info_installer_tous_documents' => 'تثبيت كل المستندات',
	'info_largeur' => 'عرض',
	'info_logo_max_taille' => 'يجب ألا يتعدى حجم الرموز @maxi@ (يبلغ حجم الملف الحالي @actuel@). ',
	'info_mode' => 'الوضعية',
	'info_modifier_document' => 'تعديل المستند',
	'info_portfolio' => 'صالة العرض',
	'info_referencer_doc_distant' => 'تبويب مستند على شبكة انترنت:',
	'info_resolution_image' => 'الدقة',
	'info_resolution_mpx' => '@resolution@ ميغا نقطة',
	'info_sans_vignette' => 'بدون مصغر',
	'info_statut_document' => 'هذا المستند:',
	'info_taille' => 'الحجم',
	'info_telecharger' => 'تحميل من جهازك:',
	'info_utilisation' => 'يستخدمه',
	'infos' => 'معلومات تقنية',
	'item_autoriser_selectionner_date_en_ligne' => 'السماح بتعديل تاريخ كل مستند',
	'item_non_autoriser_selectionner_date_en_ligne' => 'تاريخ المستندات هو تاريخ تحميلهم في الموقع',

	// L
	'label_activer_document_objets' => 'تفعيل التنزيل في المحتوى:',
	'label_apercu' => 'معاينة',
	'label_caracteristiques' => 'المواصفات',
	'label_credits' => 'الحقوق',
	'label_fichier' => 'ملف',
	'label_fichier_vignette' => 'مصغر',
	'label_paginer_par' => 'تصفح حسب:',
	'label_parents' => 'هذا المستند مرتبط بـ',
	'label_refdoc_joindre' => 'مستند رقم',
	'lien_tout_desordonner' => 'إعادة تأصيل الترتيب',
	'lien_tout_desordonner_verif' => 'سيتم إعادة تأصيل ترتيب هذه اللائحة. هل تؤكدون ذلك؟',
	'lien_tout_enlever' => 'إزالة الكل',
	'logo' => 'رمز',

	// M
	'media_audio' => 'شريط صوتي',
	'media_file' => 'مستندات أخرى',
	'media_image' => 'صور',
	'media_video' => 'مقطع فيديو',
	'miniature_automatique_active' => 'سيقوم SPIP يإنشاء مصغر من الصورة آلياً',

	// N
	'nb_documents_attache_succes' => 'تمت فعلاً إضافة @nb@ مستند',
	'nb_documents_installe_succes' => 'تم تحميل @nb@ ملف بنجاح',

	// O
	'objet_document' => 'مستند',
	'objet_documents' => 'مستندات',
	'ordonner_ce_document' => 'ترتيب هذا المستند',

	// P
	'par_date' => 'تاريخ',
	'par_hauteur' => 'ارتفاع',
	'par_id' => 'رقم',
	'par_largeur' => 'عرض',
	'par_taille' => 'حجم',
	'par_titre' => 'عنوان',

	// T
	'texte_documents_joints' => 'يمكنك تفعيل واجهة إضافة مستندات (ملفات مكتبية، صور، وسائط متعددة، الخ.) الى المقالات والأقسام وغيرها. ويمكن حينها ادراج هذه الملفات في المقال او عرضها منفصلة.',
	'texte_documents_joints_2' => 'هذا الإعداد لا يمنع تنزيل الصور في المقالات ولا إدراج المستندات مباشرة في نصوص المحتوى.',
	'titre_documents_joints' => 'المستندات المرفقة',
	'titre_page_documents_edit' => 'تعديل المستند: @titre@',
	'tous_les_medias' => 'كل الوسائط',
	'tout_dossier_upload' => 'كامل الدليل @upload@',
	'tout_voir' => 'عرض الكل',

	// U
	'un_audio' => 'شريط صوتي واحد',
	'un_document' => '1 مستند',
	'un_file' => '1 مستند',
	'un_image' => '1 صورة',
	'un_video' => 'مقطع فيديو واحد',
	'une_utilisation' => '1 استخدام',
	'upload_fichier_zip' => 'ملف ZIP',
	'upload_fichier_zip_texte' => 'الملف الذي تنوي تثبيته هو ملف ZIP.',
	'upload_fichier_zip_texte2' => 'قد يكون هذا الملف:',
	'upload_info_mode_document' => 'وضع في صالة العرض',
	'upload_info_mode_image' => 'إزالة من صالة العرض',
	'upload_limit' => 'هذا الملف كبير جداً لجهاز الخدمة. الحجم الاقصى المسموح به خلال <i>التحميل</i> هو @max@. ',
	'upload_zip_conserver' => 'الحفاظ على الملف المضغوط بعد سحب المحتوى',
	'upload_zip_decompacter' => 'غير مضغوط و كل عنصر يحتويه مثبت في الموقع. الملفات التي سيتم تثبيتها في الموقع هي:',
	'upload_zip_mode_document' => 'وضع كل الصور في صالة العرض',
	'upload_zip_telquel' => 'مثبت كما هو على شكل ملف ZIP مضغوط.',
	'upload_zip_titrer' => 'عنونة حسب اسماء الملفات',

	// V
	'verifier_documents_brises' => 'التدقيق في الملفات المفقودة',
	'verifier_documents_inutilises' => 'التدقيق في روابط المستندات',
	'vignette_supprimee' => 'تم حذف المصغر'
);

==> spip_4.0.4.orig.tar.xz: plugins-dist/medias/lang/medias_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'affichage_documents_en_cases' => 'عرض في خانات',
	'affichage_documents_en_grand' => 'عرض كبير',
	'affichage_documents_en_liste_compacte' => 'عرض في لائحة موجزة',
	'aucun_audio' => 'لا يوجد ملفات صوت',
	'aucun_document' => 'لا يوجد مستندات',
	'aucun_file' => 'لا يوجد مستندات',
	'aucun_image' => 'لا يوجد صور',
	'aucun_video' => 'لا يوجد ملفات فيديو',
	'aucune_utilisation' => 'هذا المستند غير مستخدم',
	'aucune_vignette' => 'لا يوجد مصغرات',

	// B
	'bouton_ajouter_document' => 'إضافة مستند',
	'bouton_ajouter_image' => 'إضافة صورة',
	'bouton_ajouter_image_document' => 'إضافة صورة أو مستند',
	'bouton_attacher_document' => 'ربط
',
	'bouton_copier_local' => 'نسخ في الموقع',
	'bouton_download_depuis' => 'من:',
	'bouton_download_local' => 'جهازي',
	'bouton_download_par_ftp' => 'جهاز الخدمة',
	'bouton_download_par_mediatheque' => 'مكتبة المستندات',
	'bouton_download_sur_le_web' => 'شبكة إنترنت',
	'bouton_enlever_document' => 'إزالة الربط',
	'bouton_enlever_supprimer_document' => 'حذف',
	'bouton_enlever_supprimer_document_confirmation' => 'هل تريد فعلاً حذف المستند؟',
	'bouton_modifier_document' => 'تعديل',
	'bouton_parcourir' => 'عرض...',
	'bouton_refresh_document' => 'تحديث المستند',
	'bouton_remplacer_document' => 'تبديل هذا المستند',
	'bouton_remplacer_image' => 'تبديل هذه الصورة',
	'bouton_remplacer_image_document' => 'استبدال بصورة إو مستند',
	'bouton_supprimer' => 'حذف',
	'bouton_supprimer_tous_orphelins' => 'حذف كل المستندات غير المستخدمة',
	'bouton_supprimer_tous_orphelins_confirmation' => 'هل تريد فعلاً حذف @nb@ مستند غير مستخدم؟',
	'bouton_upload' => 'تنزيل',

	// D
	'des_audios' => '@nb@ ملف صوت',
	'des_documents' => '@nb@ مستند',
	'des_files' => '@nb@ مستند',
	'des_images' => '@nb@ صورة',
	'des_utilisations' => '@nb@ استخدام',
	'des_videos' => '@nb@ ملف فيديو',
	'descriptif' => 'وصف',
	'details_document' => 'التفاصيل',
	'details_document_afficher_masquer' => 'عرض \\ حجب تفاصيل المستند',
	'document_attache_succes' => 'لقد تمت فعلاً إضافة المستند',
	'document_copie_locale_succes' => 'لقد تم فعلاً نسخ الملف في الموقع',
	'document_installe_succes' => 'لقد تم فعلاً تحميل الملف',
	'document_vu' => 'مدرج في النص',
	'documents' => 'مكتبة المستندات',
	'documents_brises' => 'رابط مكسور',
	'documents_distants' => 'بعيدة',
	'documents_locaux' => 'محلية',
	'documents_non_publies' => 'غير منشورة',
	'documents_orphelins' => 'غير مستخدمة',
	'documents_publies' => 'منشورة',
	'documents_tous' => 'الكل',
	'double_clic_inserer_doc' => 'النقر المزدوج لإدراج هذا الاختصار في النص',

	// E
	'entree_dimensions' => 'الحجم:',
	'entree_titre_document' => 'اسم المستند:',
	'entree_titre_image' => 'اسم الصورة:',
	'erreur_aucun_document' => 'لا وجود لهذا المستند في المكتبة',
	'erreur_aucun_fichier' => 'لم يتم العثور على أي ملف',
	'erreur_autorisation' => 'فشل الاجازة',
	'erreur_chemin_distant' => 'لم يتم العثور على الملف البعيد @nom@',
	'erreur_chemin_ftp' => 'لم يتم العثور على الملف المحدد في الخادم',
	'erreur_copie_fichier' => 'لا يمكن نسخ الملف @nom@',
	'erreur_deplacement_impossible' => 'النقل مسحيل.',
	'erreur_dossier_tmp_manquant' => 'مجلد مؤقت لتحميل الملفات غير موجود',
	'erreur_ecriture_fichier' => 'حصل خطأ خلال كتابة الملف على القرص الثابت',
	'erreur_format_fichier_image' => 'لا يناسب تنسيق @nom@ ملف صورة',
	'erreur_indiquez_un_fichier' => 'تحديد ملف!',
	'erreur_insertion_document_base' => 'لا يمكن تسجيل المستند @fichier@ في قاعدة البيانات',
	'erreur_objet_absent' => 'المعلومات المستقاة غير كاملة.',
	'erreur_suppression_vignette' => 'حصل خطأ لدى حذف المصغر',
	'erreur_upload_type_interdit' => 'تحميل ملفات من نوع @nom@ غير مسموح',
	'erreur_upload_vignette' => 'خطأ خلال تحميل المصغر @nom@',
	'erreurs' => '@nb@ خطأ',
	'erreurs_voir' => 'عرض @nb@ خطأ',

	// F
	'fichier_distant' => 'ملف بعيد',
	'fichier_manquant' => 'ملف غير موجود',
	'fichier_modifie' => 'تم تعديل هذا المستند. أنقر على حفظ.',
	'format_date_incorrect' => 'التاريخ او الوقت غير صحيحين',

	// I
	'icone_creer_document' => 'إضافة مستند',
	'id' => 'رقم',
	'image_tourner_180' => 'دوران 180°',
	'image_tourner_droite' => 'دوران 90° يمين',
	'image_tourner_gauche' => 'دوران 90° يسار',
	'info_alt' => 'وصف محتوى الصورة عندما تكون مخفية، إضافة الر العن،ان.',
	'info_dimensions_image' => 'الأبعاد',
	'info_doc_max_poids' => 'يحب ان يكون حجم المستندات أقل من @maxi@ (حجم هذا الملف يبلغ @actuel@).',
	'info_document' => 'المستند',
	'info_document_indisponible' => 'هذا المستند غير متوافر',
	'info_documents' => 'المستندات',
	'info_duree' => 'المدة',
	'info_gauche_numero_document' => 'مستند رقم',
	'info_hauteur' => 'ارتفاع',
	'info_heure' => 'الساعة',
	'info_illustrations' => 'الرسوم التوضيحية',
	'info_image_max_poids' => 'يحب ان يكون حجم الصور أقل من @maxi@ (حجم هذا الملف يبلغ @actuel@).',
	'info_image_max_taille' => 'يحب ان يكون حجم الصور أقل من @maxi@ (حجم هذا الملف يبلغ @actuel@).',
	'info_image_min_taille' => 'يجب على الصور ان تكون @mini@ على الأقل (هذا الملف يبلغ @actuel@).',
	'info_inclusion_directe' => 'ضم مباشر:',
	'info_inclusion_vignette' => 'ضم المصغر:',
	'info_installer_tous_documents' => 'تثبيت كل المستندات',
	'info_largeur' => 'عرض',
	'info_logo_max_taille' => 'يجب ألا يتعدى حجم الرموز @maxi@ (يبلغ حجم الملف الحالي @actuel@). ',
	'info_mode' => 'الوضعية',
	'info_modifier_document' => 'تعديل المستند',
	'info_portfolio' => 'صالة العرض',
	'info_referencer_doc_distant' => 'تبويب مستند على شبكة انترنت:',
	'info_resolution_image' => 'الدقة',
	'info_resolution_mpx' => '@resolution@ ميغا نقطة',
	'info_sans_vignette' => 'بدون مصغر',
	'info_statut_document' => 'هذا المستند:',
	'info_taille' => 'الحجم',
	'info_telecharger' => 'تحميل من جهازك:',
	'info_utilisation' => 'يستخدمه',
	'infos' => 'معلومات تقنية',
	'inserer_raccourci' => 'إدراج هذا المختصر في النص',
	'item_autoriser_selectionner_date_en_ligne' => 'السماح بتعديل تاريخ كل مستند',
	'item_non_autoriser_selectionner_date_en_ligne' => 'تاريخ المستندات هو تاريخ تحميلهم في الموقع',

	// L
	'label_activer_document_objets' => 'تفعيل التنزيل في المحتوى:',
	'label_alt' => 'بديل نصي (alt)',
	'label_apercu' => 'معاينة',
	'label_caracteristiques' => 'المواصفات',
	'label_credits' => 'الحقوق',
	'label_fichier' => 'ملف',
	'label_fichier_vignette' => 'مصغر',
	'label_paginer_par' => 'تصفح حسب:',
	'label_parents' => 'هذا المستند مرتبط بـ',
	'label_refdoc_joindre' => 'مستند رقم',
	'label_titre_mimetype' => 'نوع الملفات',
	'lien_tout_desordonner' => 'إعادة تأصيل الترتيب',
	'lien_tout_desordonner_verif' => 'سيتم إعادة تأصيل ترتيب هذه اللائحة. هل تؤكدون ذلك؟',
	'lien_tout_enlever' => 'فك ربط الكل',
	'lien_tout_enlever_verif' => 'هل تريدون فك ربط كل المستندات؟',
	'logo' => 'رمز',

	// M
	'media_audio' => 'شريط صوتي',
	'media_file' => 'مستندات أخرى',
	'media_image' => 'صور',
	'media_video' => 'مقطع فيديو',
	'miniature_automatique_active' => 'سيقوم SPIP يإنشاء مصغر من الصورة آلياً',

	// N
	'nb_documents_attache_succes' => 'تمت فعلاً إضافة @nb@ مستند',
	'nb_documents_installe_succes' => 'تم تحميل @nb@ ملف بنجاح',

	// O
	'objet_document' => 'مستند',
	'objet_documents' => 'مستندات',
	'ordonner_ce_document' => 'ترتيب هذا المستند',

	// P
	'par_date' => 'تاريخ',
	'par_hauteur' => 'ارتفاع',
	'par_id' => 'رقم',
	'par_largeur' => 'عرض',
	'par_taille' => 'حجم',
	'par_titre' => 'عنوان',

	// T
	'texte_documents_joints' => 'يمكنك تفعيل واجهة إضافة مستندات (ملفات مكتبية، صور، وسائط متعددة، الخ.) الى المقالات والأقسام وغيرها. ويمكن حينها ادراج هذه الملفات في المقال او عرضها منفصلة.',
	'texte_documents_joints_2' => 'هذا الإعداد لا يمنع تنزيل الصور في المقالات ولا إدراج المستندات مباشرة في نصوص المحتوى.',
	'titre_documents_joints' => 'المستندات المرفقة',
	'titre_page_documents_edit' => 'تعديل المستند: @titre@',
	'tous_les_medias' => 'كل الوسائط',
	'tout_dossier_upload' => 'كامل الدليل @upload@',
	'tout_voir' => 'عرض الكل',

	// U
	'un_audio' => 'شريط صوتي واحد',
	'un_document' => '1 مستند',
	'un_file' => '1 مستند',
	'un_image' => '1 صورة',
	'un_video' => 'مقطع فيديو واحد',
	'une_utilisation' => '1 استخدام',
	'upload_fichier_zip' => 'ملف ZIP',
	'upload_fichier_zip_texte' => 'الملف الذي تنوي تثبيته هو ملف ZIP.',
	'upload_fichier_zip_texte2' => 'قد يكون هذا الملف:',
	'upload_info_mode_document' => 'وضع في صالة العرض',
	'upload_info_mode_image' => 'إزالة من صالة العرض',
	'upload_limit' => 'هذا الملف كبير جداً لجهاز الخدمة. الحجم الاقصى المسموح به خلال <i>التحميل</i> هو @max@. ',
	'upload_zip_conserver' => 'الحفاظ على الملف المضغوط بعد سحب المحتوى',
	'upload_zip_decompacter' => 'غير مضغوط و كل عنصر يحتويه مثبت في الموقع. الملفات التي سيتم تثبيتها في الموقع هي:',
	'upload_zip_mode_document' => 'وضع كل الصور في صالة العرض',
	'upload_zip_telquel' => 'مثبت كما هو على شكل ملف ZIP مضغوط.',
	'upload_zip_titrer' => 'عنونة حسب اسماء الملفات',

	// V
	'verifier_documents_brises' => 'التدقيق في الملفات المفقودة',
	'verifier_documents_inutilises' => 'التدقيق في روابط المستندات',
	'vignette_supprimee' => 'تم حذف المصغر'
);
